pub enum ReadProcessor {
None,
RC4 {
alg: HashAlgorithm,
key: Rc4,
mac_secret: Vec<u8>,
seq: u64,
},
}Expand description
Handler for processing messages that have been read and turning them into their actual messages
Variants
None
NO-OP Write processor which directly converts the message to Message
RC4
RC4 Decryption processor which decrypts the message before converting
Implementations
Sourceimpl ReadProcessor
impl ReadProcessor
pub fn process( &mut self, message: OpaqueMessage, ) -> Result<Message, DecryptError>