SERVER_KEY

Struct SERVER_KEY 

pub struct SERVER_KEY { /* private fields */ }
RSA private key used by the server

Methods from Deref<Target = RsaPrivateKey>

pub fn to_public_key(&self) -> RsaPublicKey

Get the public key from the private key, cloning n and e.

Generally this is not needed since RsaPrivateKey implements the PublicKey trait, but it can occasionally be useful to discard the private information entirely.

pub fn dp(&self) -> Option<&BigUint>

Returns the precomputed dp value, D mod (P-1)

pub fn dq(&self) -> Option<&BigUint>

Returns the precomputed dq value, D mod (Q-1)

pub fn qinv(&self) -> Option<&BigInt>

Returns the precomputed qinv value, Q^-1 mod P

pub fn d(&self) -> &BigUint

Returns the private exponent of the key.

pub fn primes(&self) -> &[BigUint]

Returns the prime factors.

pub fn crt_coefficient(&self) -> Option<BigUint>

Compute CRT coefficient: (1/q) mod p.

pub fn validate(&self) -> Result<(), Error>

Performs basic sanity checks on the key. Returns Ok(()) if everything is good, otherwise an appropriate error.

pub fn decrypt( &self, padding: PaddingScheme, ciphertext: &[u8], ) -> Result<Vec<u8>, Error>

Decrypt the given message.

pub fn decrypt_blinded<R>( &self, rng: &mut R, padding: PaddingScheme, ciphertext: &[u8], ) -> Result<Vec<u8>, Error>
where R: RngCore + CryptoRng,

Decrypt the given message.

Uses rng to blind the decryption process.

pub fn sign( &self, padding: PaddingScheme, digest_in: &[u8], ) -> Result<Vec<u8>, Error>

Sign the given digest.

pub fn sign_with_rng<R>( &self, rng: &mut R, padding: PaddingScheme, digest_in: &[u8], ) -> Result<Vec<u8>, Error>
where R: RngCore + CryptoRng,

Sign the given digest using the provided rng

Use rng for signature process.

pub fn sign_blinded<R>( &self, rng: &mut R, padding: PaddingScheme, digest_in: &[u8], ) -> Result<Vec<u8>, Error>
where R: RngCore + CryptoRng,

Sign the given digest.

Use rng for blinding.

Methods from Deref<Target = RsaPublicKey>

pub const MIN_PUB_EXPONENT: u64 = 2

pub const MAX_PUB_EXPONENT: u64

pub const MAX_SIZE: usize = 4096